r'''
# netapp-fsxn-snapshotpolicy

> AWS CDK [L1 construct](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html) and data structures for the [AWS CloudFormation Registry](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry.html) type `NetApp::FSxN::SnapshotPolicy` v1.1.0.

## Description

A snapshot policy specifies when to create snapshots, how many to retain, and how to name them. A snapshot policy automatically creates and manages snapshots for a volume at defined intervals. The policy simplifies backup scheduling and maintains a reliable set of recovery points. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.

## References

* [Source](https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider)

## Usage

In order to use this library, you will need to activate this AWS CloudFormation Registry type in your account. You can do this via the AWS Management Console or using the [AWS CLI](https://aws.amazon.com/cli/) using the following command:

```sh
aws cloudformation activate-type \
  --type-name NetApp::FSxN::SnapshotPolicy \
  --publisher-id a25d267c2b9b86b8d408fce3c7a4d94d34c90946 \
  --type RESOURCE \
  --execution-role-arn ROLE-ARN
```

Alternatively:

```sh
aws cloudformation activate-type \
  --public-type-arn arn:aws:cloudformation:us-east-1::type/resource/a25d267c2b9b86b8d408fce3c7a4d94d34c90946/NetApp-FSxN-SnapshotPolicy \
  --execution-role-arn ROLE-ARN
```

You can find more information about activating this type in the [AWS CloudFormation documentation](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html).

## Feedback

This library is auto-generated and published to all supported programming languages by the [cdklabs/cdk-cloudformation](https://github.com/cdklabs/cdk-cloudformation) project based on the API schema published for `NetApp::FSxN::SnapshotPolicy`.

* Issues related to this generated library should be [reported here](https://github.com/cdklabs/cdk-cloudformation/issues/new?title=Issue+with+%40cdk-cloudformation%2Fnetapp-fsxn-snapshotpolicy+v1.1.0).
* Issues related to `NetApp::FSxN::SnapshotPolicy` should be reported to the [publisher](https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider).

## License

Distributed under the Apache-2.0 License.
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import typeguard
from importlib.metadata import version as _metadata_package_version
TYPEGUARD_MAJOR_VERSION = int(_metadata_package_version('typeguard').split('.')[0])

def check_type(argname: str, value: object, expected_type: typing.Any) -> typing.Any:
    if TYPEGUARD_MAJOR_VERSION <= 2:
        return typeguard.check_type(argname=argname, value=value, expected_type=expected_type) # type:ignore
    else:
        if isinstance(value, jsii._reference_map.InterfaceDynamicProxy): # pyright: ignore [reportAttributeAccessIssue]
           pass
        else:
            if TYPEGUARD_MAJOR_VERSION == 3:
                typeguard.config.collection_check_strategy = typeguard.CollectionCheckStrategy.ALL_ITEMS # type:ignore
                typeguard.check_type(value=value, expected_type=expected_type) # type:ignore
            else:
                typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore

from ._jsii import *

import aws_cdk as _aws_cdk_ceddda9d
import constructs as _constructs_77d1e7e8


class CfnSnapshotPolicy(
    _aws_cdk_ceddda9d.CfnResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshotpolicy.CfnSnapshotPolicy",
):
    '''A CloudFormation ``NetApp::FSxN::SnapshotPolicy``.

    :cloudformationResource: NetApp::FSxN::SnapshotPolicy
    :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
    '''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        copies: typing.Sequence[typing.Union["SnapshotPolicyCopy", typing.Dict[builtins.str, typing.Any]]],
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
        name: builtins.str,
        svm: typing.Optional[typing.Union["Svm", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''Create a new ``NetApp::FSxN::SnapshotPolicy``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param copies: The snapshot copies that define the policy.
        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.
        :param name: The name of the snapshot policy.
        :param svm: The SVM information associated with the snapshot policy.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__622f6507eb4f7bb2b4b7ac307a4508288259de49dc875508cb40ceb1f0d3e914)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        props = CfnSnapshotPolicyProps(
            copies=copies,
            file_system_id=file_system_id,
            fsx_admin_password_source=fsx_admin_password_source,
            link_arn=link_arn,
            name=name,
            svm=svm,
        )

        jsii.create(self.__class__, self, [scope, id, props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
        '''The CloudFormation resource type name for this resource class.'''
        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))

    @builtins.property
    @jsii.member(jsii_name="attrUuid")
    def attr_uuid(self) -> builtins.str:
        '''Attribute ``NetApp::FSxN::SnapshotPolicy.UUID``.

        :link: https://github.com/NetApp/NetApp-CloudFormation-FSx-ONTAP-provider
        '''
        return typing.cast(builtins.str, jsii.get(self, "attrUuid"))

    @builtins.property
    @jsii.member(jsii_name="props")
    def props(self) -> "CfnSnapshotPolicyProps":
        '''Resource props.'''
        return typing.cast("CfnSnapshotPolicyProps", jsii.get(self, "props"))


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshotpolicy.CfnSnapshotPolicyProps",
    jsii_struct_bases=[],
    name_mapping={
        "copies": "copies",
        "file_system_id": "fileSystemId",
        "fsx_admin_password_source": "fsxAdminPasswordSource",
        "link_arn": "linkArn",
        "name": "name",
        "svm": "svm",
    },
)
class CfnSnapshotPolicyProps:
    def __init__(
        self,
        *,
        copies: typing.Sequence[typing.Union["SnapshotPolicyCopy", typing.Dict[builtins.str, typing.Any]]],
        file_system_id: builtins.str,
        fsx_admin_password_source: typing.Union["PasswordSource", typing.Dict[builtins.str, typing.Any]],
        link_arn: builtins.str,
        name: builtins.str,
        svm: typing.Optional[typing.Union["Svm", typing.Dict[builtins.str, typing.Any]]] = None,
    ) -> None:
        '''A snapshot policy specifies when to create snapshots, how many to retain, and how to name them.

        A snapshot policy automatically creates and manages snapshots for a volume at defined intervals. The policy simplifies backup scheduling and maintains a reliable set of recovery points. Once activated, you need a preview key to consume this resource. Please reach out to Ng-fsx-cloudformation@netapp.com to get the key. To use this resource, you must first create the Link module.

        :param copies: The snapshot copies that define the policy.
        :param file_system_id: The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.
        :param fsx_admin_password_source: The password source for the FSx admin user.
        :param link_arn: The ARN of the AWS Lambda function that will be invoked to manage the resource.
        :param name: The name of the snapshot policy.
        :param svm: The SVM information associated with the snapshot policy.

        :schema: CfnSnapshotPolicyProps
        '''
        if isinstance(fsx_admin_password_source, dict):
            fsx_admin_password_source = PasswordSource(**fsx_admin_password_source)
        if isinstance(svm, dict):
            svm = Svm(**svm)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3fa593828214dce76f30cea021cdd5a4c875c71352dada1f39f8dbb5e69769d2)
            check_type(argname="argument copies", value=copies, expected_type=type_hints["copies"])
            check_type(argname="argument file_system_id", value=file_system_id, expected_type=type_hints["file_system_id"])
            check_type(argname="argument fsx_admin_password_source", value=fsx_admin_password_source, expected_type=type_hints["fsx_admin_password_source"])
            check_type(argname="argument link_arn", value=link_arn, expected_type=type_hints["link_arn"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument svm", value=svm, expected_type=type_hints["svm"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "copies": copies,
            "file_system_id": file_system_id,
            "fsx_admin_password_source": fsx_admin_password_source,
            "link_arn": link_arn,
            "name": name,
        }
        if svm is not None:
            self._values["svm"] = svm

    @builtins.property
    def copies(self) -> typing.List["SnapshotPolicyCopy"]:
        '''The snapshot copies that define the policy.

        :schema: CfnSnapshotPolicyProps#Copies
        '''
        result = self._values.get("copies")
        assert result is not None, "Required property 'copies' is missing"
        return typing.cast(typing.List["SnapshotPolicyCopy"], result)

    @builtins.property
    def file_system_id(self) -> builtins.str:
        '''The file system ID of the Amazon FSx for NetApp ONTAP file system in which the resource is created.

        :schema: CfnSnapshotPolicyProps#FileSystemId
        '''
        result = self._values.get("file_system_id")
        assert result is not None, "Required property 'file_system_id' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def fsx_admin_password_source(self) -> "PasswordSource":
        '''The password source for the FSx admin user.

        :schema: CfnSnapshotPolicyProps#FsxAdminPasswordSource
        '''
        result = self._values.get("fsx_admin_password_source")
        assert result is not None, "Required property 'fsx_admin_password_source' is missing"
        return typing.cast("PasswordSource", result)

    @builtins.property
    def link_arn(self) -> builtins.str:
        '''The ARN of the AWS Lambda function that will be invoked to manage the resource.

        :schema: CfnSnapshotPolicyProps#LinkArn
        '''
        result = self._values.get("link_arn")
        assert result is not None, "Required property 'link_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''The name of the snapshot policy.

        :schema: CfnSnapshotPolicyProps#Name
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def svm(self) -> typing.Optional["Svm"]:
        '''The SVM information associated with the snapshot policy.

        :schema: CfnSnapshotPolicyProps#SVM
        '''
        result = self._values.get("svm")
        return typing.cast(typing.Optional["Svm"], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CfnSnapshotPolicyProps(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshotpolicy.PasswordSource",
    jsii_struct_bases=[],
    name_mapping={"secret": "secret"},
)
class PasswordSource:
    def __init__(
        self,
        *,
        secret: typing.Union["SecretSource", typing.Dict[builtins.str, typing.Any]],
    ) -> None:
        '''
        :param secret: A reference to the source of the password, typically an AWS Secrets Manager secret.

        :schema: PasswordSource
        '''
        if isinstance(secret, dict):
            secret = SecretSource(**secret)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__1c504d31f450b0f8f1e50c973a0d97dd26c6ac5c7cd22d3b9caab5813c2f542c)
            check_type(argname="argument secret", value=secret, expected_type=type_hints["secret"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "secret": secret,
        }

    @builtins.property
    def secret(self) -> "SecretSource":
        '''A reference to the source of the password, typically an AWS Secrets Manager secret.

        :schema: PasswordSource#Secret
        '''
        result = self._values.get("secret")
        assert result is not None, "Required property 'secret' is missing"
        return typing.cast("SecretSource", result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PasswordSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshotpolicy.SecretSource",
    jsii_struct_bases=[],
    name_mapping={"secret_arn": "secretArn", "secret_key": "secretKey"},
)
class SecretSource:
    def __init__(self, *, secret_arn: builtins.str, secret_key: builtins.str) -> None:
        '''
        :param secret_arn: The ARN of the secret stored in AWS Secrets Manager.
        :param secret_key: Reference for the SecretKey. The actual password is stored in AWS Secret Manager.

        :schema: SecretSource
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__63ddeceaa4cc3ecb91e7285b012541debc6a777626d432d67b93e34eeec7755b)
            check_type(argname="argument secret_arn", value=secret_arn, expected_type=type_hints["secret_arn"])
            check_type(argname="argument secret_key", value=secret_key, expected_type=type_hints["secret_key"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "secret_arn": secret_arn,
            "secret_key": secret_key,
        }

    @builtins.property
    def secret_arn(self) -> builtins.str:
        '''The ARN of the secret stored in AWS Secrets Manager.

        :schema: SecretSource#SecretArn
        '''
        result = self._values.get("secret_arn")
        assert result is not None, "Required property 'secret_arn' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def secret_key(self) -> builtins.str:
        '''Reference for the SecretKey.

        The actual password is stored in AWS Secret Manager.

        :schema: SecretSource#SecretKey
        '''
        result = self._values.get("secret_key")
        assert result is not None, "Required property 'secret_key' is missing"
        return typing.cast(builtins.str, result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshotpolicy.SnapshotPolicyCopy",
    jsii_struct_bases=[],
    name_mapping={
        "count": "count",
        "schedule_name": "scheduleName",
        "prefix": "prefix",
        "retention_period": "retentionPeriod",
        "snapmirror_label": "snapmirrorLabel",
    },
)
class SnapshotPolicyCopy:
    def __init__(
        self,
        *,
        count: jsii.Number,
        schedule_name: builtins.str,
        prefix: typing.Optional[builtins.str] = None,
        retention_period: typing.Optional[builtins.str] = None,
        snapmirror_label: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param count: The number of snapshot copies to maintain for this schedule.
        :param schedule_name: Schedule name at which snapshot copies are captured on the volume.
        :param prefix: The prefix to use while creating snapshot copies at regular intervals.
        :param retention_period: Specifies the retention period of snapshot copies. The retention value represents a duration and must follow the ISO-8601 duration format. The retention period can be in years, months, days, hours, or minutes. For example 'P10Y' represents a duration of 10 years. The retention string must contain only a single time element (years, months, days, hours, or minutes).
        :param snapmirror_label: Label for SnapMirror operations. SnapMirror Label name must contain at least one character and must not contain leading or trailing white space.

        :schema: SnapshotPolicyCopy
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__3410c66f03fc1235810e2044f46232cae20d88b8dced8c2c21e90f10c4cb88b0)
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument schedule_name", value=schedule_name, expected_type=type_hints["schedule_name"])
            check_type(argname="argument prefix", value=prefix, expected_type=type_hints["prefix"])
            check_type(argname="argument retention_period", value=retention_period, expected_type=type_hints["retention_period"])
            check_type(argname="argument snapmirror_label", value=snapmirror_label, expected_type=type_hints["snapmirror_label"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "count": count,
            "schedule_name": schedule_name,
        }
        if prefix is not None:
            self._values["prefix"] = prefix
        if retention_period is not None:
            self._values["retention_period"] = retention_period
        if snapmirror_label is not None:
            self._values["snapmirror_label"] = snapmirror_label

    @builtins.property
    def count(self) -> jsii.Number:
        '''The number of snapshot copies to maintain for this schedule.

        :schema: SnapshotPolicyCopy#Count
        '''
        result = self._values.get("count")
        assert result is not None, "Required property 'count' is missing"
        return typing.cast(jsii.Number, result)

    @builtins.property
    def schedule_name(self) -> builtins.str:
        '''Schedule name at which snapshot copies are captured on the volume.

        :schema: SnapshotPolicyCopy#ScheduleName
        '''
        result = self._values.get("schedule_name")
        assert result is not None, "Required property 'schedule_name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def prefix(self) -> typing.Optional[builtins.str]:
        '''The prefix to use while creating snapshot copies at regular intervals.

        :schema: SnapshotPolicyCopy#Prefix
        '''
        result = self._values.get("prefix")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def retention_period(self) -> typing.Optional[builtins.str]:
        '''Specifies the retention period of snapshot copies.

        The retention value represents a duration and must follow the ISO-8601 duration format. The retention period can be in years, months, days, hours, or minutes. For example 'P10Y' represents a duration of 10 years. The retention string must contain only a single time element (years, months, days, hours, or minutes).

        :schema: SnapshotPolicyCopy#RetentionPeriod
        '''
        result = self._values.get("retention_period")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def snapmirror_label(self) -> typing.Optional[builtins.str]:
        '''Label for SnapMirror operations.

        SnapMirror Label name must contain at least one character and must not contain leading or trailing white space.

        :schema: SnapshotPolicyCopy#SnapmirrorLabel
        '''
        result = self._values.get("snapmirror_label")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotPolicyCopy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@cdk-cloudformation/netapp-fsxn-snapshotpolicy.Svm",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "uuid": "uuid"},
)
class Svm:
    def __init__(
        self,
        *,
        name: typing.Optional[builtins.str] = None,
        uuid: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param name: The name of the SVM.
        :param uuid: The UUID of the SVM.

        :schema: SVM
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__287a048a7bda088a210350943f8cdbeed3f4e0f19f167596bd448a9fe3d6a1f1)
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument uuid", value=uuid, expected_type=type_hints["uuid"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if name is not None:
            self._values["name"] = name
        if uuid is not None:
            self._values["uuid"] = uuid

    @builtins.property
    def name(self) -> typing.Optional[builtins.str]:
        '''The name of the SVM.

        :schema: SVM#Name
        '''
        result = self._values.get("name")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def uuid(self) -> typing.Optional[builtins.str]:
        '''The UUID of the SVM.

        :schema: SVM#UUID
        '''
        result = self._values.get("uuid")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Svm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "CfnSnapshotPolicy",
    "CfnSnapshotPolicyProps",
    "PasswordSource",
    "SecretSource",
    "SnapshotPolicyCopy",
    "Svm",
]

publication.publish()

def _typecheckingstub__622f6507eb4f7bb2b4b7ac307a4508288259de49dc875508cb40ceb1f0d3e914(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    copies: typing.Sequence[typing.Union[SnapshotPolicyCopy, typing.Dict[builtins.str, typing.Any]]],
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
    name: builtins.str,
    svm: typing.Optional[typing.Union[Svm, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3fa593828214dce76f30cea021cdd5a4c875c71352dada1f39f8dbb5e69769d2(
    *,
    copies: typing.Sequence[typing.Union[SnapshotPolicyCopy, typing.Dict[builtins.str, typing.Any]]],
    file_system_id: builtins.str,
    fsx_admin_password_source: typing.Union[PasswordSource, typing.Dict[builtins.str, typing.Any]],
    link_arn: builtins.str,
    name: builtins.str,
    svm: typing.Optional[typing.Union[Svm, typing.Dict[builtins.str, typing.Any]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__1c504d31f450b0f8f1e50c973a0d97dd26c6ac5c7cd22d3b9caab5813c2f542c(
    *,
    secret: typing.Union[SecretSource, typing.Dict[builtins.str, typing.Any]],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__63ddeceaa4cc3ecb91e7285b012541debc6a777626d432d67b93e34eeec7755b(
    *,
    secret_arn: builtins.str,
    secret_key: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__3410c66f03fc1235810e2044f46232cae20d88b8dced8c2c21e90f10c4cb88b0(
    *,
    count: jsii.Number,
    schedule_name: builtins.str,
    prefix: typing.Optional[builtins.str] = None,
    retention_period: typing.Optional[builtins.str] = None,
    snapmirror_label: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__287a048a7bda088a210350943f8cdbeed3f4e0f19f167596bd448a9fe3d6a1f1(
    *,
    name: typing.Optional[builtins.str] = None,
    uuid: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass
